#include "TinyMqtt.h"   // https://github.com/hsaturn/TinyMqtt
#include <WiFi.h>
#include <WiFiAP.h>
#include "M5StickCPlus.h"

#define PORT 1883
MqttBroker broker(PORT);

#define pinPower 26

/** Programme M5stack de la roue
  *
  *  Il crée un wi-fi et héberge un broker du MQTT
	*  Le programme envoie dans la patte de sortie une tension reçue par MQTT
  */

const char* ssid = "froll_n_roll";
const char* password = "test_froll";

MqttClient mqtt_client(&broker);

void setup()
{

  // Initialisation Ecran
  Serial.begin(115200);

  M5.begin();
  M5.Lcd.setTextSize(3);
  M5.Lcd.setRotation(3);  

  // Création reseau wi-fi
	if (strlen(ssid)==0)
		Console << TinyConsole::red << "****** PLEASE MODIFY ssid/password *************" << endl;

  WiFi.softAP(ssid, password);
  IPAddress myIP = WiFi.softAPIP();
  Serial.print("AP IP address: ");
  Serial.println(myIP);

  // Démarrage broker

  broker.begin();
  Console << "Broker ready : " << WiFi.localIP() << " ; " << myIP << " on port " << PORT << endl;

  // Connexion au topic 
  mqtt_client.setCallback(CallBack);
  mqtt_client.subscribe("roue_master");
  
  // Démarrage différé par rapport au moteur
  delay(1000);
  Serial.println("Topic demandé");
  for(int i=0;i<193; i++){
    dacWrite(pinPower, i);
    delay(10);
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print(i);
  }

 
}

/*
 * Cette fonction est appelé à chaque fois qu'un message est posté sur un topic où l'on est abonné
*/
void CallBack(const MqttClient* source, const Topic& topic, const char* payload, size_t payload_length)
{
  Serial.println(payload);
  dacWrite(pinPower, atoi(payload));
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.print(payload);
}



void loop()
{
  broker.loop();
  mqtt_client.loop(); 
}
